@@ -581,7 +581,7 @@ gtk_level_bar_size_allocate (GtkWidget     *widget,
 {
   GTK_WIDGET_CLASS (gtk_level_bar_parent_class)->size_allocate (widget, allocation);
 
-  _gtk_widget_set_simple_clip (widget);
+  _gtk_widget_set_simple_clip (widget, NULL);
 }
 
 static void
