@@ -789,6 +789,8 @@ gtk_paned_init (GtkPaned *paned)
   priv->handle_pos.x = -1;
   priv->handle_pos.y = -1;
 
+  _gtk_orientable_set_style_classes (GTK_ORIENTABLE (paned));
+
   gesture = gtk_gesture_pan_new (GTK_WIDGET (paned),
                                  GTK_ORIENTATION_HORIZONTAL);
   gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (gesture), FALSE);
@@ -1156,9 +1158,9 @@ gtk_paned_get_preferred_size (GtkWidget      *widget,
   GtkPanedPrivate *priv = paned->priv;
 
   if (orientation == priv->orientation)
-    return gtk_paned_get_preferred_size_for_orientation (widget, size, minimum, natural);
+    gtk_paned_get_preferred_size_for_orientation (widget, size, minimum, natural);
   else
-    return gtk_paned_get_preferred_size_for_opposite_orientation (widget, size, minimum, natural);
+    gtk_paned_get_preferred_size_for_opposite_orientation (widget, size, minimum, natural);
 }
 
 static void
