@@ -268,6 +268,7 @@ static void gtk_spin_button_get_frame_size (GtkEntry *entry,
                                             gint     *y,
                                             gint     *width,
                                             gint     *height);
+static void gtk_spin_button_unset_adjustment (GtkSpinButton *spin_button);
 static void gtk_spin_button_set_orientation (GtkSpinButton     *spin_button,
                                              GtkOrientation     orientation);
 static void gtk_spin_button_snap           (GtkSpinButton      *spin_button,
@@ -574,8 +575,6 @@ gtk_spin_button_set_property (GObject      *object,
 
     case PROP_ADJUSTMENT:
       adjustment = GTK_ADJUSTMENT (g_value_get_object (value));
-      if (!adjustment)
-        adjustment = gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
       gtk_spin_button_set_adjustment (spin_button, adjustment);
       break;
     case PROP_CLIMB_RATE:
@@ -716,8 +715,7 @@ gtk_spin_button_init (GtkSpinButton *spin_button)
 
   priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 
-  gtk_spin_button_set_adjustment (spin_button,
-                                  gtk_adjustment_new (0, 0, 0, 0, 0, 0));
+  gtk_spin_button_set_adjustment (spin_button, NULL);
 
   context = gtk_widget_get_style_context (GTK_WIDGET (spin_button));
   gtk_style_context_add_class (context, GTK_STYLE_CLASS_SPINBUTTON);
@@ -726,6 +724,7 @@ gtk_spin_button_init (GtkSpinButton *spin_button)
   gtk_widget_add_events (GTK_WIDGET (spin_button), GDK_SCROLL_MASK);
 
   priv->swipe_gesture = gtk_gesture_swipe_new (GTK_WIDGET (spin_button));
+  gtk_gesture_single_set_touch_only (GTK_GESTURE_SINGLE (priv->swipe_gesture), TRUE);
   gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (priv->swipe_gesture),
                                               GTK_PHASE_CAPTURE);
   g_signal_connect (priv->swipe_gesture, "begin",
@@ -740,7 +739,7 @@ gtk_spin_button_finalize (GObject *object)
   GtkSpinButton *spin_button = GTK_SPIN_BUTTON (object);
   GtkSpinButtonPrivate *priv = spin_button->priv;
 
-  gtk_spin_button_set_adjustment (spin_button, NULL);
+  gtk_spin_button_unset_adjustment (spin_button);
 
   if (priv->down_panel_context)
     g_object_unref (priv->down_panel_context);
@@ -1097,7 +1096,7 @@ gtk_spin_button_realize (GtkWidget *widget)
   attributes.event_mask = gtk_widget_get_events (widget);
   attributes.event_mask |= GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK
     | GDK_BUTTON_RELEASE_MASK | GDK_LEAVE_NOTIFY_MASK | GDK_ENTER_NOTIFY_MASK
-    | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK;
+    | GDK_POINTER_MOTION_MASK;
 
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
 
@@ -1159,6 +1158,37 @@ gtk_spin_button_unrealize (GtkWidget *widget)
     }
 }
 
+/* Callback used when the spin button's adjustment changes.
+ * We need to redraw the arrows when the adjustment’s range
+ * changes, and reevaluate our size request.
+ */
+static void
+adjustment_changed_cb (GtkAdjustment *adjustment, gpointer data)
+{
+  GtkSpinButton *spin_button = GTK_SPIN_BUTTON (data);
+  GtkSpinButtonPrivate *priv = spin_button->priv;
+
+  priv->timer_step = gtk_adjustment_get_step_increment (priv->adjustment);
+  gtk_widget_queue_resize (GTK_WIDGET (spin_button));
+}
+
+static void
+gtk_spin_button_unset_adjustment (GtkSpinButton *spin_button)
+{
+  GtkSpinButtonPrivate *priv = spin_button->priv;
+
+  if (priv->adjustment)
+    {
+      g_signal_handlers_disconnect_by_func (priv->adjustment,
+                                            gtk_spin_button_value_changed,
+                                            spin_button);
+      g_signal_handlers_disconnect_by_func (priv->adjustment,
+                                            adjustment_changed_cb,
+                                            spin_button);
+      g_clear_object (&priv->adjustment);
+    }
+}
+
 static void
 gtk_spin_button_set_orientation (GtkSpinButton *spin,
                                  GtkOrientation orientation)
@@ -2106,12 +2136,28 @@ gtk_spin_button_configure (GtkSpinButton *spin_button,
 
   priv = spin_button->priv;
 
-  if (adjustment)
-    gtk_spin_button_set_adjustment (spin_button, adjustment);
-  else
+  if (!adjustment)
     adjustment = priv->adjustment;
 
   g_object_freeze_notify (G_OBJECT (spin_button));
+  if (priv->adjustment != adjustment)
+    {
+      gtk_spin_button_unset_adjustment (spin_button);
+
+      priv->adjustment = adjustment;
+      g_object_ref_sink (adjustment);
+      g_signal_connect (adjustment, "value-changed",
+                        G_CALLBACK (gtk_spin_button_value_changed),
+                        spin_button);
+      g_signal_connect (adjustment, "changed",
+                        G_CALLBACK (adjustment_changed_cb),
+                        spin_button);
+      priv->timer_step = gtk_adjustment_get_step_increment (priv->adjustment);
+
+      g_object_notify (G_OBJECT (spin_button), "adjustment");
+      gtk_widget_queue_resize (GTK_WIDGET (spin_button));
+    }
+
   if (priv->digits != digits)
     {
       priv->digits = digits;
@@ -2206,20 +2252,6 @@ gtk_spin_button_new_with_range (gdouble min,
   return GTK_WIDGET (spin);
 }
 
-/* Callback used when the spin button's adjustment changes.
- * We need to redraw the arrows when the adjustment’s range
- * changes, and reevaluate our size request.
- */
-static void
-adjustment_changed_cb (GtkAdjustment *adjustment, gpointer data)
-{
-  GtkSpinButton *spin_button = GTK_SPIN_BUTTON (data);
-  GtkSpinButtonPrivate *priv = spin_button->priv;
-
-  priv->timer_step = gtk_adjustment_get_step_increment (priv->adjustment);
-  gtk_widget_queue_resize (GTK_WIDGET (spin_button));
-}
-
 /**
  * gtk_spin_button_set_adjustment:
  * @spin_button: a #GtkSpinButton
@@ -2237,35 +2269,13 @@ gtk_spin_button_set_adjustment (GtkSpinButton *spin_button,
 
   priv = spin_button->priv;
 
-  if (priv->adjustment != adjustment)
-    {
-      if (priv->adjustment)
-        {
-          g_signal_handlers_disconnect_by_func (priv->adjustment,
-                                                gtk_spin_button_value_changed,
-                                                spin_button);
-          g_signal_handlers_disconnect_by_func (priv->adjustment,
-                                                adjustment_changed_cb,
-                                                spin_button);
-          g_object_unref (priv->adjustment);
-        }
-      priv->adjustment = adjustment;
-      if (adjustment)
-        {
-          g_object_ref_sink (adjustment);
-          g_signal_connect (adjustment, "value-changed",
-                            G_CALLBACK (gtk_spin_button_value_changed),
-                            spin_button);
-          g_signal_connect (adjustment, "changed",
-                            G_CALLBACK (adjustment_changed_cb),
-                            spin_button);
-          priv->timer_step = gtk_adjustment_get_step_increment (priv->adjustment);
-        }
+  if (!adjustment)
+    adjustment = gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 
-      gtk_widget_queue_resize (GTK_WIDGET (spin_button));
-    }
-
-  g_object_notify (G_OBJECT (spin_button), "adjustment");
+  gtk_spin_button_configure (spin_button,
+                             adjustment,
+                             priv->climb_rate,
+                             priv->digits);
 }
 
 /**
